@@ -7,19 +7,16 @@ use parent 'Exporter';
 use charnames qw( :full );
 use Carp;
 
-our $VERSION     = '0.07';
-our @EXPORT      = qw( dump_hex dump_dec dump_oct dump_bin dump_names );
-our %EXPORT_TAGS = ( all => \@EXPORT );
-
-# TODO: remove this after a while
-sub import {
-    my ($class, @symbols) = @_;
-    carp 'Implicitly importing String::Dump functions is deprecated and will '
-       . 'be disabled in an upcoming release'
-        unless @symbols;
-    local $Exporter::ExportLevel = 1;
-    $class->SUPER::import(@symbols);
-}
+our $VERSION = '0.08';
+our @EXPORT_OK = qw(
+    dump_hex
+    dump_dec
+    dump_oct
+    dump_bin
+    dump_names
+    dump_codes
+);
+our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
 sub dump_hex {
     my ($str) = @_;
@@ -58,11 +55,18 @@ sub dump_names {
            split '', $str;
 }
 
+sub dump_codes {
+    my ($str) = @_;
+    carp('dump_codes() expects one argument') && return if @_ != 1;
+    return unless defined $str;
+    return join ' ', map { sprintf 'U+%04X', ord } split '', $str;
+}
+
 1;
 
 __END__
 
-=encoding utf8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -70,37 +74,31 @@ String::Dump - Dump strings of characters (or bytes) for printing and debugging
 
 =head1 VERSION
 
-This document describes String::Dump version 0.07.
+This document describes String::Dump version 0.08.
 
 =head1 SYNOPSIS
 
-    use String::Dump qw( dump_hex dump_oct );
+    use String::Dump qw( dump_hex dump_bin );
 
     say 'hex: ', dump_hex($string);
-    say 'oct: ', dump_oct($string);
+    say 'bin: ', dump_bin($string);
 
 =head1 DESCRIPTION
 
-When debugging or reviewing strings containing non-ASCII or non-printing
-characters, String::Dump is your friend.  It provides simple functions to
-return a dump of the characters or bytes (octets) of your string in several
-different formats, such as hex, octal, decimal, Unicode names, and more.
+When debugging or examining strings containing non-ASCII or non-printing
+characters, String::Dump is your friend.  It provides simple functions to return
+a dump of the code points for Unicode strings or the bytes for byte strings in
+several different formats, such as hex, binary, Unicode names, and more.
 
-An OO interface is forthcoming with additional options and the ability to
-reuse them among multiple calls.  Some benefits will include the ability to
-set the delimiter between character dumps, set padding for the characters,
-or only dump non-ASCII characters.  Don’t worry, the standard functions will
-remain simple.
-
-Check out L<String::Dump::Debugging> for tips on debugging Unicode and encoded
-strings with this module.  Also check out the bundled command-line tool
-L<dumpstr>.
+For using this module from the command line, see the bundled L<dumpstr> script.
+For tips on debugging Unicode or byte strings with this module, see the document
+L<String::Dump::Debugging>.
 
 =head1 FUNCTIONS
 
 These functions all accept a single argument: the string to dump, which may
-either be a Perl internal string or an encoded series of bytes.  Each has to
-be explicitly exported or they can all be exported with the C<:all> tag.
+either be a Unicode string or a byte string.  Each function has to be explicitly
+exported or they can all be exported with the C<:all> tag.
 
     use String::Dump qw( :all );
 
@@ -122,7 +120,8 @@ For a lowercase hex dump, simply pass the response to C<lc>.
 
 =head2 dump_dec($string)
 
-Decimal (base 10) mode.
+Decimal (base 10) mode.  This is mainly useful when referencing 8-bit code pages
+like ISO-8859-1 or 7-bit ones like ASCII variants.
 
     use utf8;
     say dump_dec('Ĝis! ☺');  # 284 105 115 33 32 9786
@@ -132,7 +131,8 @@ Decimal (base 10) mode.
 
 =head2 dump_oct($string)
 
-Octal (base 8) mode.
+Octal (base 8) mode.  This is mainly useful when referencing 7-bit code pages
+like ASCII variants.
 
     use utf8;
     say dump_oct('Ĝis! ☺');  # 434 151 163 41 40 23072
@@ -154,26 +154,28 @@ Binary (base 2) mode.
 
 =head2 dump_names($string)
 
-Named Unicode character mode.  Unlike the various numeral modes above, this
-mode uses ‘, ’ (comma, space) for the delimiter.
+Unicode character name mode.  Unlike the various numeral modes above, this mode
+uses “, ” <comma, space> for the delimiter and it only makes sense for Unicode
+strings, not byte strings.
 
     use utf8;
     say dump_names('Ĝis! ☺');
     # LATIN CAPITAL LETTER G WITH CIRCUMFLEX, LATIN SMALL LETTER I,
     # LATIN SMALL LETTER S, EXCLAMATION MARK, SPACE, WHITE SMILING FACE
 
-This mode makes no sense for a series of bytes, but it still works if that’s
-what you really want!
+The output in the example above has been manually split into multiple lines for
+the layout of this document.
 
-    no utf8;
-    say dump_names('Ĝis! ☺');
-    # LATIN CAPITAL LETTER A WITH DIAERESIS, STRING TERMINATOR,
-    # LATIN SMALL LETTER I, LATIN SMALL LETTER S, EXCLAMATION MARK,
-    # SPACE, LATIN SMALL LETTER A WITH CIRCUMFLEX, START OF STRING,
-    # MASCULINE ORDINAL INDICATOR
+=head2 dump_codes($string)
 
-The output in the examples above has been manually split into multiple lines
-for the layout of this document.
+Unicode code point mode.  This is similar to C<dump_hex> except it follows the
+standard Unicode code point notation.  The hex value is 4 to 6 digits, padded
+with “0” <digit zero> when less than 4, and prefixed with “U+” <latin capital
+letter u, plus sign>.  As with C<dump_names>, this function only makes sense for
+Unicode strings, not byte strings.
+
+    use utf8;
+    say dump_codes('Ĝis! ☺');  # U+011C U+0069 U+0073 U+0021 U+0020 U+263A
 
 =head1 SEE ALSO
 
